Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(550)

Unified Diff: minidump/test/minidump_writable_test_util.h

Issue 1311003003: Implement ModuleSnapshotWin::UUID (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: fixes Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « minidump/minidump_module_writer_test.cc ('k') | minidump/test/minidump_writable_test_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: minidump/test/minidump_writable_test_util.h
diff --git a/minidump/test/minidump_writable_test_util.h b/minidump/test/minidump_writable_test_util.h
index ac7ac03860964a16a98d2033cc24266ea6649ef7..ce489686a09efe29a6b84dd535a30484b29d59c9 100644
--- a/minidump/test/minidump_writable_test_util.h
+++ b/minidump/test/minidump_writable_test_util.h
@@ -98,8 +98,8 @@ MINIDUMP_ALLOW_OVERSIZED_DATA(MinidumpSimpleStringDictionary);
// data).
MINIDUMP_ALLOW_OVERSIZED_DATA(IMAGE_DEBUG_MISC);
MINIDUMP_ALLOW_OVERSIZED_DATA(MINIDUMP_STRING);
-MINIDUMP_ALLOW_OVERSIZED_DATA(MinidumpModuleCodeViewRecordPDB20);
-MINIDUMP_ALLOW_OVERSIZED_DATA(MinidumpModuleCodeViewRecordPDB70);
+MINIDUMP_ALLOW_OVERSIZED_DATA(CodeViewRecordPDB20);
+MINIDUMP_ALLOW_OVERSIZED_DATA(CodeViewRecordPDB70);
MINIDUMP_ALLOW_OVERSIZED_DATA(MinidumpUTF8String);
// minidump_file_writer_test accesses its variable-sized test streams via a
@@ -142,10 +142,10 @@ const T* TMinidumpWritableAtLocationDescriptor(
//! specializations ensure that the size given by \a location matches the
//! size expected of a stream containing the number of elements it claims to
//! have.
//! - With an IMAGE_DEBUG_MISC, MinidumpModuleCodeViewRecordPDB20, or
//! MinidumpModuleCodeViewRecordPDB70 template parameter, template
//! specializations ensure that the structure has the expected format
//! including any magic number and the `NUL`-terminated string.
//!
//! \param[in] file_contents The contents of the minidump file.
//! \param[in] location A MINIDUMP_LOCATION_DESCRIPTOR giving the offset within
@@ -190,16 +190,14 @@ const MINIDUMP_THREAD_LIST* MinidumpWritableAtLocationDescriptor<
const MINIDUMP_LOCATION_DESCRIPTOR& location);
template <>
-const MinidumpModuleCodeViewRecordPDB20*
-MinidumpWritableAtLocationDescriptor<MinidumpModuleCodeViewRecordPDB20>(
- const std::string& file_contents,
- const MINIDUMP_LOCATION_DESCRIPTOR& location);
+const CodeViewRecordPDB20* MinidumpWritableAtLocationDescriptor<
+ CodeViewRecordPDB20>(const std::string& file_contents,
+ const MINIDUMP_LOCATION_DESCRIPTOR& location);
template <>
-const MinidumpModuleCodeViewRecordPDB70*
-MinidumpWritableAtLocationDescriptor<MinidumpModuleCodeViewRecordPDB70>(
- const std::string& file_contents,
- const MINIDUMP_LOCATION_DESCRIPTOR& location);
+const CodeViewRecordPDB70* MinidumpWritableAtLocationDescriptor<
+ CodeViewRecordPDB70>(const std::string& file_contents,
+ const MINIDUMP_LOCATION_DESCRIPTOR& location);
template <>
const MinidumpModuleCrashpadInfoList*
« no previous file with comments | « minidump/minidump_module_writer_test.cc ('k') | minidump/test/minidump_writable_test_util.cc » ('j') | no next file with comments »
@@ -142,10 +142,10 @@ const T* TMinidumpWritableAtLocationDescriptor(
//! size expected of a stream containing the number of elements it claims to
//! have.
-//! - With an IMAGE_DEBUG_MISC, MinidumpModuleCodeViewRecordPDB20, or
-//! MinidumpModuleCodeViewRecordPDB70 template parameter, template
-//! specializations ensure that the structure has the expected format
-//! including any magic number and the `NUL`-terminated string.
+//! - With an IMAGE_DEBUG_MISC, CodeViewRecordPDB20, or CodeViewRecordPDB70
+//! template parameter, template specializations ensure that the structure
+//! has the expected format including any magic number and the `NUL`-
+//! terminated string.
//!
//! \param[in] file_contents The contents of the minidump file.

Powered by Google App Engine
This is Rietveld 408576698